OC.L10N.register(
    "survey_client",
    {
    "Last report sent on: {on}" : "上次發送報告的時間：{on}",
    "An error occurred while sending your report." : "送出報告時發生錯誤。",
    "App list <em>(for each app: name, version, enabled status)</em>" : "App 列表<em>（針對每個應用：名稱，版本，啟用狀態）</em>",
    "Database environment <em>(type, version, database size)</em>" : "數據庫環境<em>（類型，版本，數據庫大小）</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "加密信息<em>（啟用了嗎？默認模塊是什麼？）</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "分享數量<em>（按類型和權限設置）</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "PHP環境<em>（版本，內存限制，最大執行時間，最大文件大小）</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "伺服器站台詳細資料<em>（版本、是否使用 memcache、鎖定／預覽／虛擬化身照的狀態）</em>",
    "Statistic <em>(number of files, users, storages per type, comments and tags)</em>" : "統計信息<em>（文件，用戶，每種類型的存儲，註釋和標籤的數量）</em>",
    "Usage survey" : "用量調查",
    "Help improve Nextcloud" : "幫助改善Nextcloud",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "您是否想通過提供一些有關您的設置和使用情況的匿名數據來幫助我們改善Nextcloud？ 您可以隨時在管理設置中再次禁用它。",
    "Send usage" : "發送使用情況數據",
    "Not now" : "現在不了",
    "Never" : "絕不",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud." : "將匿名數據發送到Nextcloud，以幫助我們改進Nextcloud。",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud. You\n\t\talways have full control over the content sent to Nextcloud and can disable\n\t\tit again at any time." : "將匿名數據發送到 Nextcloud，以幫助我們改進 Nextcloud。你一律完全控制發送到 Nextcloud 的內容，並且可以隨時禁用。",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "您可以通過向我們發送一些有關當前設置和使用情況的數據來幫助改進Nextcloud。",
    "Send new report now" : "立即發送新報告",
    "Send usage survey monthly" : "每月發送使用情況調查",
    "Data to send" : "要發送的數據",
    "Last report sent on: %s" : "上次發送報告的時間：%s",
    "Last report" : "上次發送的報告"
},
"nplurals=1; plural=0;");
